#
# spec file for package python-argparse-manpage
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define mod_name argparse-manpage
Name:           python-argparse-manpage
Version:        4.6
Release:        3.1
Summary:        Tool for automatic manual page building from a Python ArgumentParser object
License:        Apache-2.0
URL:            https://github.com/praiskup/argparse-manpage
Source:         https://github.com/praiskup/argparse-manpage/archive/v%{version}.tar.gz
BuildArch:      noarch
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools-wheel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  ca-certificates
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
%if 0%{python_version_nodots} < 311
Requires:       python-tomli
%endif
Requires(post): update-alternatives
Requires(postun): update-alternatives
%python_subpackages

%description
This utility generates a manual page in an automatic way from an
ArgumentParser object, so the manpage 1:1 corresponds to the
automatically generated --help output. The manpage generator needs to
known the location of the object, user can specify that by (a) the
module name or corresponding python filename and (b) the object name
or the function name which returns the object. There's a limited
support for (deprecated) optparse objects, too.

%prep
%autosetup -p1 -n %{mod_name}-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/argparse-manpage
%python_clone -a %{buildroot}%{_mandir}/man1/argparse-manpage.1
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export PIP_NO_INDEX=1
export PIP_FIND_LINKS=$(ls -1 /usr/lib/python3.*/wheels | head -n 1)
%pytest -k 'not test_old_example_file_name'

%post
%{python_install_alternative argparse-manpage argparse-manpage.1}

%postun
%python_uninstall_alternative argparse-manpage

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/argparse_manpage
%{python_sitelib}/build_manpages
%{python_sitelib}/argparse_manpage-%{version}.dist-info
%python_alternative %{_bindir}/argparse-manpage
%python_alternative %{_mandir}/man1/argparse-manpage.1%{?ext_man}

%changelog
* Tue Apr  1 2025 Steve Kowalik <steven.kowalik@suse.com>
- Skip a failing test.
* Wed Jan  8 2025 Steve Kowalik <steven.kowalik@suse.com>
- Drop patch skip-pip-install.patch:
  * Point pip to the directory that setuptools-wheel uses, since that is
    the only requirement for pip install with the current version of
    setuptools.
- Remove unneeded Requires, limit them appropiately.
- Switch to pyproject macros.
* Wed Jun 12 2024 Dirk Müller <dmueller@suse.com>
- update to 4.6:
  * Fix build against Python 3.13
* Mon Oct  2 2023 Dirk Müller <dmueller@suse.com>
- update to 4.5:
  * We newly provide build_manpages.build_py and build_manpages.install
    command classes that are re-usable from pyproject.toml.
    No need to provide setup.py because of argparse-manpage.
  * The prog= specifier (in setup.py/setup.cfg/pyproject.toml) is
    now better handled so it doesn't conflict with
    ArgumentParser(prog=..).
* Thu Jun 15 2023 Steve Kowalik <steven.kowalik@suse.com>
- Update to 4.3:
  * The pyproject.toml parsing feature now depends on tomli
  * Support for pyproject.toml specification of manpages added.
  * Support for pre-written man pages (the --manfile option)
  * Incorrect dict access for --include support fixed.
- Add patch skip-pip-install.patch:
  * Skip pip install tests for now.
* Sun Apr 16 2023 Dirk Müller <dmueller@suse.com>
- update to 4.1:
  * A new `--include` feature, inspired by `help2man --include`.
  * Allow overriding build date with SOURCE_DATE_EPOCH
    environment variable in order to make builds reproducible.
* Mon Nov  7 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to v4
  News in v4
  The manual page generator logic is now separated from the 'build_manpages'
  module (which provides setup.py integration helpers). Therefore the
  argparse-manpage doesn't necessarily have to depend on setuptools.
  Projects that want to integrate using 'setup.py' should though place a new
  "extra" named 'argparse-manpage[setuptools]' into their set of build
  requirements in project.toml file.
  The old 'build_manpage' command (!= 'build_manpages') is now more
  isolated from the rest of the code, likely never loaded.
  the Manpage class API was changed in v3 so it required an additional
  constructor 'data' argument. This change was reverted, and the only
  argument is again the ArgumentParser object.
  The 'version' and 'description' options were fixed.
  New options 'manual_section' and 'manual_title' were added.
  The manual page now automatically generates a current date in headers.
  Several groff escaping issues were fixed.
* Thu Oct 20 2022 Daniel Garcia <daniel.garcia@suse.com>
- Remove not needed dep python-six
* Thu Aug  4 2022 Daniel Mach <daniel.mach@suse.com>
- Update to 3
  * New man page format: single-commands-section
  * Add CLI and conf options for setting the output format
  * Add CLI and conf options to explicitly specify %%prog value
  * Skip showing commands with help == SUPPRESS
  * Avoid rendering docs for command aliases
  * Print program name in upper case in header and footer
  * The --author CLI option has changed, and takes arbitrary string
    (typically 'Author Name <the@example.com>'), and newly can be specified
    multiple times.  Therefore, it now replaces the '--author-email' option.
    The --author-email option is kept, but is just an alias to the --author
    option.
  * All CLI options can be specified also in setup.cfg
  * Don't render AUTHORS and DISTRIBUTION if they would contain undefined values
  * Remove '... was written by' from AUTHORS
  * Fixed the testsuite against the setuptools v60+
  * Output manual pages should be built reproducibly, no matter the current
    size of the terminal.
  * Methods build_manpages, get_build_py_cmd, get_install_cmd are now
    provided in top-level module.
  * More portable opening and parsing given by python file name.
  * Split out options by generic argument groups, not only predefined
    "positional arguments", "options", and Subparsers.
  * Drop python3-six requirement.
  * Properly highligh all option argument METAVARs.
- spec changes:
  * BuildArch set to noarch
  * Add build dependency on pip module
* Tue Apr 20 2021 Markéta Machová <mmachova@suse.com>
- Update to 1.5
  * fixed testsuite for Python 3.9
  * The "epilog" from argparse object is dumped to "COMMENTS" sections.
* Thu Aug 20 2020 Marketa Calabkova <mcalabkova@suse.com>
- Resubmit for SLE (jsc#SLE-12826)
* Tue Apr 14 2020 Matej Cepl <mcepl@suse.com>
- Don't use %%python3_only command, but properly use alternatives.
* Fri Jan 31 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Require python-setuotools: /usr/bin/argparse-manpage does
  from pkg_resources import load_entry_point.
* Fri Jan 17 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 1.3
  * drop additional .br tag from paragraphs so the multiline text is nicer
  * provide argparse-manpage via entry_point
* Fri Sep 13 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.2.2:
  * More complete release tarball, including tests.
  * Fixed shebang in /bin/argparse-manpage script so it works on
    Debian/Ubuntu as well as on Fedora.
  * LICENSE file included in release tarball.
  * Command-line executable now takes an optional '--output' argument.
* Tue May  7 2019 Tomáš Chvátal <tchvatal@suse.com>
- Switch to github tarball
  - Enable tests
  - Get license file
- Run fdupes
- Add support for older distros than Tumbleweed
* Fri Oct 12 2018 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summary. Repair grammar issues in description.
* Thu Oct 11 2018 Marcus Rueckert <mrueckert@suse.de>
- initial package
